#!/bin/bash

# Without vector extension, gcc, gcc-llvm and clang

FLAGS="-O3 -march=core2"
CC="gcc -DGCC"
CCDESCR="gcc llvm 4.2"

echo $CC $FLAGS  vectors.c -o vectors
$CC $FLAGS  vectors.c -o vectors
echo Compiler $CCDESCR
echo Flags $FLAGS
time ./vectors x
echo

FLAGS="-O3 -march=core2"
CC="gcc-4.2 -DGCC"
CCDESCR="gcc 4.2"

$CC $FLAGS  vectors.c -o vectors
echo Compiler $CCDESCR
echo Flags $FLAGS
time ./vectors x
echo

FLAGS="-O3 -march=core2"
CC="clang -DGCC"
CCDESCR="clang"

$CC $FLAGS  vectors.c -o vectors
echo Compiler $CCDESCR
echo Flags $FLAGS
time ./vectors x
echo

# With Vector Extensions, size 8

FLAGS="-O3 -march=core2"
CC="gcc -DGCC -DHAS_VECT8_EXT"
CCDESCR="gcc llvm 4.2 vector extensions, size 8"

$CC $FLAGS  vectors.c -o vectors
echo Compiler $CCDESCR
echo Flags $FLAGS
time ./vectors x
echo

FLAGS="-O3 -march=core2"
CC="gcc-4.2 -DGCC -DHAS_VECT8_EXT"
CCDESCR="gcc 4.2 vector extensions, size 8"

$CC $FLAGS  vectors.c -o vectors
echo Compiler $CCDESCR
echo Flags $FLAGS
time ./vectors x
echo

FLAGS="-O3 -march=core2"
CC="clang -DGCC -DHAS_VECT8_EXT"
CCDESCR="clang vector extensions, size 8"

$CC $FLAGS  vectors.c -o vectors
echo Compiler $CCDESCR
echo Flags $FLAGS
time ./vectors x
echo


# With Vector Extensions, size 4

FLAGS="-O3 -march=core2"
CC="gcc -DGCC -DHAS_VECT4_EXT"
CCDESCR="gcc llvm 4.2 vector extensions, size 4"

$CC $FLAGS  vectors.c -o vectors
echo Compiler $CCDESCR
echo Flags $FLAGS
time ./vectors x
echo

FLAGS="-O3 -march=core2"
CC="gcc-4.2 -DGCC -DHAS_VECT4_EXT"
CCDESCR="gcc 4.2 vector extensions, size 4"

$CC $FLAGS  vectors.c -o vectors
echo Compiler $CCDESCR
echo Flags $FLAGS
time ./vectors x
echo

FLAGS="-O3 -march=core2"
CC="clang -DGCC -DHAS_VECT4_EXT"
CCDESCR="clang vector extensions, size 4"

$CC $FLAGS  vectors.c -o vectors
echo Compiler $CCDESCR
echo Flags $FLAGS
time ./vectors x
echo

# gcc only, ss2 and ss3

FLAGS="-O3 -march=core2 -msse2 -ffast-math"
CC="gcc-4.2 -DGCC -DHAS_VECT4_EXT"
CCDESCR="gcc 4.2 vector extensions, size 4"

$CC $FLAGS  vectors.c -o vectors
echo Compiler $CCDESCR
echo Flags $FLAGS
time ./vectors x
echo

FLAGS="-O3 -march=core2 -msse3 -ffast-math"
CC="gcc-4.2 -DGCC -DHAS_VECT4_EXT"
CCDESCR="gcc 4.2 vector extensions, size 4"

$CC $FLAGS  vectors.c -o vectors
echo Compiler $CCDESCR
echo Flags $FLAGS
time ./vectors x
echo
